==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/GenerateToCreatorSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.GenerateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateToCreator;
import io.ciera.tool.sql.ooaofooa.event.GenerateToCreatorSet;
import io.ciera.tool.sql.ooaofooa.event.impl.GenerateSMEventStatementSetImpl;

import java.util.Arrays;
import java.util.List;


public class GenerateToCreatorSetImpl extends InstanceSet<GenerateToCreatorSet,GenerateToCreator> implements GenerateToCreatorSet {

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( GenerateToCreator generatetocreator : this ) generatetocreator.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public GenerateSMEventStatementSet R705_is_a_GenerateSMEventStatement() throws XtumlException {
        GenerateSMEventStatementSet generatesmeventstatementset = new GenerateSMEventStatementSetImpl();
        for ( GenerateToCreator generatetocreator : this ) generatesmeventstatementset.add( generatetocreator.R705_is_a_GenerateSMEventStatement() );
        return generatesmeventstatementset;
    }


    @Override
    public GenerateToCreator nullElement() {
        return GenerateToCreatorImpl.EMPTY_GENERATETOCREATOR;
    }

    @Override
    public GenerateToCreatorSet emptySet() {
      return new GenerateToCreatorSetImpl();
    }

    @Override
    public GenerateToCreatorSet value() {
        return this;
    }

    @Override
    public List<GenerateToCreator> elements() {
        return Arrays.asList(toArray(new GenerateToCreator[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/event/impl/GenerateToCreatorSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.event.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.event.GenerateSMEventStatementSet;
import io.ciera.tool.sql.ooaofooa.event.GenerateToCreator;
import io.ciera.tool.sql.ooaofooa.event.GenerateToCreatorSet;
import io.ciera.tool.sql.ooaofooa.event.impl.GenerateSMEventStatementSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class GenerateToCreatorSetImpl extends InstanceSet<GenerateToCreatorSet,GenerateToCreator> implements GenerateToCreatorSet {

    public GenerateToCreatorSetImpl() {
    }

    public GenerateToCreatorSetImpl(Comparator<? super GenerateToCreator> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setStatement_ID( UniqueId ref_Statement_ID ) throws XtumlException {
        for ( GenerateToCreator generatetocreator : this ) generatetocreator.setStatement_ID( ref_Statement_ID );
    }


    // selections
    @Override
    public GenerateSMEventStatementSet R705_is_a_GenerateSMEventStatement() throws XtumlException {
        GenerateSMEventStatementSet generatesmeventstatementset = new GenerateSMEventStatementSetImpl();
        for ( GenerateToCreator generatetocreator : this ) generatesmeventstatementset.add( generatetocreator.R705_is_a_GenerateSMEventStatement() );
        return generatesmeventstatementset;
    }


    @Override
    public GenerateToCreator nullElement() {
        return GenerateToCreatorImpl.EMPTY_GENERATETOCREATOR;
    }

    @Override
    public GenerateToCreatorSet emptySet() {
      return new GenerateToCreatorSetImpl();
    }

    @Override
    public GenerateToCreatorSet emptySet(Comparator<? super GenerateToCreator> comp) {
      return new GenerateToCreatorSetImpl(comp);
    }

    @Override
    public GenerateToCreatorSet value() {
        return this;
    }

    @Override
    public List<GenerateToCreator> elements() {
        return Arrays.asList(toArray(new GenerateToCreator[0]));
    }

}
